==> annotrack.v3.1.tgz: annotrack/perl/modules/gencode_tracking_system/sources/mit_congo.pm <==
#!/usr/local/ensembl/bin/perl -w

# Helper script for the GENCODE tracking system, to be run nightly.
#
# Connect to the external DAS servers,
# fetch data, store in internal tracking system db
# and recalculate dependant fields in db


package gencode_tracking_system::sources::mit_congo;

use strict;
use gencode_tracking_system::core;
use gencode_tracking_system::config;
use base 'Exporter';

our @EXPORT    = qw( run_update );

sub run_update {
  my ($response, $chrom, $tracking_dbh, $prepare_hash, $user_id, $category_id, $previous_genes) = @_;

  my $gene_type   = "mit_congo_exon";
  my $gene_status = 'new';
  my %new_features = ();
  my $updated      = 0;

  my ($current_transcript_id, $current_gene_id);

  #get general project instead:
  $current_gene_id = get_project_for_category($prepare_hash, $tracking_dbh, $category_id);
  die "Can't find general project for category $category_id!\n" unless $current_gene_id;

  # go through loci
  while (my ($url, $features) = each %$response) {

    if(ref $features eq "ARRAY"){
      print "Received ".scalar @$features." features.\n" if $VERBOSE;

    FEATURES:
      foreach my $feature (@$features) {

	my $phase = "0";
	my %notes = ();
	my $i     = 0;
	while(defined($feature->{'note'}->[$i])){
	  my $morenotes = $feature->{'note'}->[$i];
	  my ($morenotes_type, $morenotes_value) = split('\|', $morenotes);
	  $morenotes_value =~ s/\&\#39\;/\'/g;
	  $notes{$morenotes_type} = $morenotes_value;
	  $i++;
	}

	my $timestamp_updated = $notes{'LASTMOD'};
	my $timestamp_created = $notes{'LASTMOD'};
#	if(defined($notes{'CREATED'})){
#	  $timestamp_created = $notes{'CREATED'};
#	}

	#remove duplicates from overlapping regions
	if(defined $previous_genes and exists $previous_genes->{$feature->{'feature_id'}}){
	  next FEATURES;
	}
	$new_features{$feature->{'feature_id'}} = 1;

	my %transcript;

	#build structure for transcript
	$transcript{'chrom'}        = $chrom;
	$transcript{'biotype'}      = $gene_type;
	$transcript{'status'}       = $gene_status;
	$transcript{'type'}         = "transcript";
	$transcript{'start'}        = $feature->{'start'};
	$transcript{'end'}          = $feature->{'end'};
	$transcript{'strand'}       = $feature->{'orientation'};
	$transcript{'id'}           = $feature->{'feature_id'};
	$transcript{'description'}  = $feature->{'feature_id'};
	$transcript{'created_on'}   = $timestamp_created;
	$transcript{'updated_on'}   = $timestamp_updated;

#	#clone gene from transcript
#	my %gene = %transcript;

#	#store gene
#	if($VERBOSE){
#	  print "GENE:\n";
#	  print_element(\%gene);
#	}
#	$gene{'type'} = "gene";
#	($current_gene_id, $updated) = store_features($tracking_dbh, $prepare_hash, \%gene, 'gene', 0, 0, 
#        				  $user_id, $category_id);

	#use general project instead

	#store transcript
	if($VERBOSE){
	  print "TRANSCRIPT:\n";
	  print_element(\%transcript);
	}
	($current_transcript_id, $updated) = store_features($tracking_dbh, $prepare_hash, \%transcript,
						'transcript', $current_gene_id, 0, 
						$user_id, $category_id);

      }
      @$features = ();
    }
  }

  return \%new_features;
}


1;

==> annotrack.v3.4.tgz: annotrack/perl/modules/gencode_tracking_system/sources/mit_congo.pm <==
#!/usr/local/ensembl/bin/perl -w

# Helper script for the GENCODE tracking system, to be run nightly.
#
# Connect to the external DAS servers,
# fetch data, store in internal tracking system db
# and recalculate dependant fields in db


package gencode_tracking_system::sources::mit_congo;

use strict;
use gencode_tracking_system::core;
use gencode_tracking_system::config;
use base 'Exporter';

our @EXPORT    = qw( run_update );

sub run_update {
  my ($response, $chrom, $tracking_dbh, $prepare_hash, $user_id, $category_id, $previous_genes) = @_;

  my $gene_type   = "mit_congo_exon";
  my $gene_status = 'new';
  my %new_features = ();
  my $updated      = 0;

  my ($current_transcript_id, $current_gene_id);

  #get general project instead:
  $current_gene_id = get_project_for_category($prepare_hash, $tracking_dbh, $category_id);
  die "Can't find general project for category $category_id!\n" unless $current_gene_id;

  # go through loci
  while (my ($url, $features) = each %$response) {

    if(ref $features eq "ARRAY"){
      print "Received ".scalar @$features." features.\n" if $VERBOSE;

    FEATURES:
      foreach my $feature (@$features) {

	my $phase = "0";
	my %notes = ();
	my $i     = 0;
	while(defined($feature->{'note'}->[$i])){
	  my $morenotes = $feature->{'note'}->[$i];
	  my ($morenotes_type, $morenotes_value) = split('\|', $morenotes);
	  $morenotes_value =~ s/\&\#39\;/\'/g;
	  $notes{$morenotes_type} = $morenotes_value;
	  $i++;
	}

	my $timestamp_updated = $notes{'LASTMOD'};
	my $timestamp_created = $notes{'LASTMOD'};
#	if(defined($notes{'CREATED'})){
#	  $timestamp_created = $notes{'CREATED'};
#	}

	#remove duplicates from overlapping regions
	if(defined $previous_genes and exists $previous_genes->{$feature->{'feature_id'}}){
	  next FEATURES;
	}
	$new_features{$feature->{'feature_id'}} = 1;

	my %transcript;

	#build structure for transcript
	$transcript{'chrom'}        = $chrom;
	$transcript{'biotype'}      = $gene_type;
	$transcript{'status'}       = $gene_status;
	$transcript{'type'}         = "transcript";
	$transcript{'start'}        = $feature->{'start'};
	$transcript{'end'}          = $feature->{'end'};
	$transcript{'strand'}       = $feature->{'orientation'};
	$transcript{'id'}           = $feature->{'feature_id'};
	$transcript{'description'}  = $feature->{'feature_id'};
	$transcript{'created_on'}   = $timestamp_created;
	$transcript{'updated_on'}   = $timestamp_updated;

	#use general project instead of individual gene - transcript pairs

	#store transcript
	if($VERBOSE){
	  print "TRANSCRIPT:\n";
	  print_element(\%transcript);
	}
	($current_transcript_id, $updated) = store_features($tracking_dbh, $prepare_hash, \%transcript,
						'transcript', $current_gene_id, 0, 
						$user_id, $category_id);

      }
      @$features = ();
    }
  }

  return \%new_features;
}


1;
